@@ -1,5 +1,5 @@
 
 # ToDo attaches
-class AllureListener(object):
+class AllureListener:
     def __init__(self, lifecycle):
         self.lifecycle = lifecycle
